summaryrefslogtreecommitdiff
path: root/src/location/declarativemaps/qdeclarativepolylinemapitem.cpp
diff options
context:
space:
mode:
authorLauri Laanmets <lauri.laanmets@eesti.ee>2021-09-30 15:10:00 +0300
committerIvan Solovev <ivan.solovev@qt.io>2021-11-09 10:28:54 +0100
commitd46a99871601ed4af1260234126c7a7e9d8f2f41 (patch)
treea89840985758f61c78d5da5986b2f5f48b3893ac /src/location/declarativemaps/qdeclarativepolylinemapitem.cpp
parentdd4211eac29aa4152d434e5960f9ba869070cb88 (diff)
downloadqtlocation-d46a99871601ed4af1260234126c7a7e9d8f2f41.tar.gz
Change 'geometryChanged' to 'geometryChange'
As stated by the documentation: https://doc.qt.io/qt-6/quick-changes-qt6.html#changes-to-qquickitem This is part of a bigger work to port QtLocation maps to Qt6. Task-number: QTBUG-96795 Change-Id: I9dcf2e454d949dfbf3a9861b98eb949be6e6df56 Reviewed-by: Ivan Solovev <ivan.solovev@qt.io> Reviewed-by: Alex Blasche <alexander.blasche@qt.io> Reviewed-by: Andreas Buhr <andreas.buhr@qt.io>
Diffstat (limited to 'src/location/declarativemaps/qdeclarativepolylinemapitem.cpp')
-rw-r--r--src/location/declarativemaps/qdeclarativepolylinemapitem.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/location/declarativemaps/qdeclarativepolylinemapitem.cpp b/src/location/declarativemaps/qdeclarativepolylinemapitem.cpp
index ee05503e..5a1419fc 100644
--- a/src/location/declarativemaps/qdeclarativepolylinemapitem.cpp
+++ b/src/location/declarativemaps/qdeclarativepolylinemapitem.cpp
@@ -1242,10 +1242,10 @@ void QDeclarativePolylineMapItem::setBackend(QDeclarativePolylineMapItem::Backen
/*!
\internal
*/
-void QDeclarativePolylineMapItem::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
+void QDeclarativePolylineMapItem::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
{
if (newGeometry.topLeft() == oldGeometry.topLeft() || !map() || !m_geopath.isValid() || m_updatingGeometry) {
- QDeclarativeGeoMapItemBase::geometryChanged(newGeometry, oldGeometry);
+ QDeclarativeGeoMapItemBase::geometryChange(newGeometry, oldGeometry);
return;
}
// TODO: change the algorithm to preserve the distances and size!
@@ -1262,7 +1262,7 @@ void QDeclarativePolylineMapItem::geometryChanged(const QRectF &newGeometry, con
m_d->onGeoGeometryChanged();
emit pathChanged();
// Not calling QDeclarativeGeoMapItemBase::geometryChanged() as it will be called from a nested
// call to this function.
}
@@ -1262,7 +1262,7 @@ void QDeclarativePolylineMapItem::geometryChanged(const QRectF &newGeometry, con
m_d->onGeoGeometryChanged();
emit pathChanged();
- // Not calling QDeclarativeGeoMapItemBase::geometryChanged() as it will be called from a nested
+ // Not calling QDeclarativeGeoMapItemBase::geometryChange() as it will be called from a nested
// call to this function.
}